ApiManager class

Constructors

ApiManager()
factory

Properties

allowMock bool
no setter
apiModels List<ApiModel>
no setter
hashCode int
The hash code for this object.
no setterinherited
mockApiHost String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

completeApiMock_whenNull({required List<ApiModel> apiModels_whenNull}) Future
初始化完成后继续完善信息,此方法只为了做测试,开发情况下使用 tryAddApi 来添加 apiModel
init() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setup({bool allowMock = false, required String mockApiHost}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ApiManager
no setter

Static Methods

changeMockForApiModel(ApiModel apiModel) → void
mockCount() int
shouldAfterMockApi(String url) bool
tryAddApi(String url, {String? name, bool isGet = false}) → void