CommonErrorRobot class

Constructors

CommonErrorRobot()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

myRobotKey String
no setter
testMarkdownContent_json → dynamic
no setter
testMarkdownContent_normal → dynamic
no setter

Static Methods

init({required String tolerantRobotKey, String? packageDescribe, String userDescribeBlock()?}) → void
post({String? robotKey, RobotPostType postType = RobotPostType.text, String? title, required String customMessage, List<String>? mentionedList}) Future<bool>
posts({List<String>? robotUrls, RobotPostType postType = RobotPostType.text, List<String>? mentionedList, String? title, required String customMessage}) Future<bool>
通用异常上报:企业微信
uploadFileByString({String? robotKey, required String fileString, required String fileName}) Future<String?>
通用异常上报:企业微信