NetworkPageDataManager class

Constructors

NetworkPageDataManager()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hasInitCompleter bool
getter/setter pair
initCompleter Completer
getter/setter pair
networkModels List<TSEnvNetworkModel>
no setter
originNetworkModel TSEnvNetworkModel
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedNetworkModel TSEnvNetworkModel
no setter

Methods

init() → dynamic
initWithDefaultNetworkIdAndModels({required List<TSEnvNetworkModel> networkModels_whenNull, required String defaultNetworkId, required bool canUseCacheNetwork}) Future<Null>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateNetworkPageSelectedData(TSEnvNetworkModel selectedNetworkModel) → dynamic
修改网络环境_页面数据

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance NetworkPageDataManager
no setter