PackageTargetType enum

发布到的平台大类型(该平台的功能类型和人群类型固定,从而决定了调用检查更新的方法)

Inheritance
Available extensions

Values

formal → const PackageTargetType
inner → const PackageTargetType
dev → const PackageTargetType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PackageTargetType>
A constant List of the values in this enum, in order of their declaration.