ProxyPageDataManager class

Constructors

ProxyPageDataManager()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hasInitCompleter bool
getter/setter pair
initCompleter Completer
getter/setter pair
proxyModels Future<List<TSEnvProxyModel>>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedProxyModel TSEnvProxyModel
no setter

Methods

addOrUpdateCustomEnvProxyIp({required String proxyName, String? proxyIp, bool selectedNew = true}) → void
addOrUpdateEnvProxyModel({required TSEnvProxyModel newProxyModel, bool selectedNew = true}) TSEnvProxyModel
getCurrentProxyIdAndModels(List<TSEnvProxyModel> proxyModels_whenNull, String defaultProxykId, bool canUseCacheProxy) Future<Null>
init() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ProxyPageDataManager
no setter