AppLogUtil class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
formatStackTrace(StackTrace? stackTrace, int methodCount)
→ String?
-
-
init({required String tolerantRobotKey, required PackageNetworkType originPackageNetworkType, required PackageNetworkType currentNetworkTypeGetBlock(), required PackageTargetType originPackageTargetType, required String packageDescribe, required String userDescribeBlock(), required bool isForceNoUploadEnvGetBlock(), required String getRobotUrlByApiHostBlock(String apiHost), required void logGenerateBlock(LogModel gLogModel), required void jsonViewOnTap(dynamic), required void jsonViewOnDoubleTap(dynamic), required void jsonViewOnLongPress(dynamic)})
→ dynamic
-
-
logMessage({required LogObjectType logType, required LogLevel logLevel, String? title, required Map shortMap, required Map detailMap, RobotPostType? postType, List<String>? mentionedList, dynamic needTackTrace = true})
→ void
-
-
logMessageWithTackTrace({required LogObjectType logType, required LogLevel logLevel, String? title, required Map shortMap, required Map detailMap, RobotPostType? postType, List<String>? mentionedList})
→ void
-
-
postToWeCom({String? title, required String customMessage})
→ Future<bool>
-