TSEnvProxyModel class
Constructors
- TSEnvProxyModel({required String proxyId, required String name, String? proxyIp, String? useDirection, bool check = false})
-
TSEnvProxyModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- check ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
getter/setter pair
- proxyId ↔ String
-
getter/setter pair
- proxyIp ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useDirection ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- noneProxykId ↔ String
-
没有使用代理
getter/setter pair
- noneProxykIp ↔ String?
-
getter/setter pair